@@ -8,12 +8,12 @@ from wtforms_components import ColorField
 class TestColorField(FormTestCase):
     def setup_method(self, method):
         self.valid_colors = [
-            '#222222',
-            'cyan',
+            "#222222",
+            "cyan",
         ]
         self.invalid_colors = [
-            'abc',
-            '#123123123',
+            "abc",
+            "#123123123",
         ]
 
     def init_form(self, **kwargs):
@@ -35,15 +35,15 @@ class TestColorField(FormTestCase):
         for color in self.invalid_colors:
             form = form_class(MultiDict(color=color))
             form.validate()
-            assert len(form.errors['color']) == 1
+            assert len(form.errors["color"]) == 1
 
     def test_field_rendering_when_validation_fails(self):
         form_class = self.init_form()
-        form = form_class(MultiDict(color='invalid'))
+        form = form_class(MultiDict(color="invalid"))
         form.validate()
         assert 'value="invalid"' in str(form.color)
 
     def test_converts_empty_strings_to_none(self):
         form_class = self.init_form()
-        form = form_class(MultiDict(color=''))
-        assert form.data == {'color': None}
+        form = form_class(MultiDict(color=""))
+        assert form.data == {"color": None}
