@@ -5,18 +5,18 @@ from wtforms_test import FormTestCase
 from wtforms_components import SelectWidget
 
 
-class Dummy(object):
+class Dummy:
     fruits = None
 
 
 class TestSelectWidgetWithNativeSelect(FormTestCase):
     choices = (
-        ('apple', 'Apple'),
-        ('peach', 'Peach'),
-        ('pear', 'Pear'),
-        ('cucumber', 'Cucumber'),
-        ('potato', 'Potato'),
-        ('tomato', 'Tomato'),
+        ("apple", "Apple"),
+        ("peach", "Peach"),
+        ("pear", "Pear"),
+        ("cucumber", "Cucumber"),
+        ("potato", "Potato"),
+        ("tomato", "Tomato"),
     )
 
     def init_form(self, **kwargs):
@@ -30,19 +30,11 @@ class TestSelectWidgetWithNativeSelect(FormTestCase):
         form_class = self.init_form(choices=self.choices)
 
         obj = Dummy()
-        obj.fruit = 'peach'
-        form = form_class(
-            obj=obj
-        )
-        assert (
-            '<option selected value="peach">Peach</option>' in
-            str(form.fruit)
-        )
+        obj.fruit = "peach"
+        form = form_class(obj=obj)
+        assert '<option selected value="peach">Peach</option>' in str(form.fruit)
 
     def test_default_value(self):
-        form_class = self.init_form(choices=self.choices, default='pear')
+        form_class = self.init_form(choices=self.choices, default="pear")
         form = form_class()
-        assert (
-            '<option selected value="pear">Pear</option>' in
-            str(form.fruit)
-        )
+        assert '<option selected value="pear">Pear</option>' in str(form.fruit)
